
% Example 'Test of Stationarity wth TF Surrogates' with a stationary ARMA process
% It serves also to test the Null Hypothesis

% pb 12/2007


%% Signal Synthesis
% (spectral mehod)

% Nx = 1024 ;
Nx = 4096 ;

polyMA = 1 ;
% polyAR = [1 -0.8 ] ;
rho = 0.99;      fc = 0.3;
a1 = -2*cos(pi*fc)*rho ;
a2 = rho^2;
polyAR = [1 a1 a2] ;

rgw = randn(Nx,1) ;

x = filter(polyMA,polyAR,rgw) ;

% roots(polyAR) 

figure(1); clf;plot(x);


%% Statistics of the test

opttfr1.choixtfr='mtfr';
opttest1=[];
opttest1.JJ=100;
optfig1=1;


[theta1,theta0,gam_hat,gam_thresh,res_test,INS,INS_thresh,opttfr,opttest]=statio_test_funct(x,opttfr1,opttest1,optfig1) ;



%% Iteration over several window length for the TFR

vNh0 = [0.015 0.03 0.05 0.1 0.15 0.2 0.25 0.3] ; 
NvNh0 = length(vNh0);

optfig1=[];

for ii=1:NvNh0,
    opttfr1.Nh0=vNh0(ii);
    [theta1,theta0,gam_hat,gam_thresh,res_test,INS,INS_thresh,opttfr,opttest]=statio_test_funct(x,opttfr1,opttest1,optfig1) ;
    
STAT(ii).Nh=opttfr.Nh;
STAT(ii).theta1=theta1;
STAT(ii).theta0=theta0;
STAT(ii).gam_hat=gam_hat;
STAT(ii).gam_thresh=gam_thresh;
STAT(ii).res_test=res_test;
STAT(ii).INS=INS;
STAT(ii).INS_thresh=INS_thresh;
STAT(ii).gam_hat=gam_hat;

end;


%%
clear res_test_tot INS_tot INS_thresh_tot gam_hat_tot

for imc=1:NvNh0,
res_test_tot(imc)=STAT(imc).res_test;
INS_tot(imc)=STAT(imc).INS;
INS_thresh_tot(imc)=STAT(imc).INS_thresh;
gam_hat_tot(:,imc)=STAT(imc).gam_hat;
end;


%% Display the results

Nhist=opttest.Nhist;
JJ=opttest.JJ;
[hh,bb] = hist(theta0,Nhist) ;
hh_est = gampdf(bb,gam_hat(1),gam_hat(2)) ;
dbb = bb(2)-bb(1) ; 

figure(21); clf;
bar(bb,hh/(JJ)/dbb)
hold on
plot(bb,hh_est,'r','LineWidth',2);
lesaxes=axis;   
plot([theta1 theta1],[lesaxes(3) lesaxes(4)],'m','LineWidth',2);
plot([gam_thresh gam_thresh],[lesaxes(3) lesaxes(4)],'k--','LineWidth',2);
hold off; 
title(['Test Result = ' num2str(res_test) ' | INS = ' num2str(INS)]);

%% Results vs. Nh0

figure(31); clf;
plot(vNh0,INS_tot,'m+-','LineWidth',2);
hold on; grid on
plot(vNh0,INS_thresh_tot,'k--','LineWidth',2);
lesaxes=axis;
lesaxes(4)=max(lesaxes(4),4);
lesaxes(3)=min(lesaxes(3),0);
axis(lesaxes);
title(['\Theta_1 in magenta, threshold in black']);





