% statio_test_theta.m
%
% Jun Xiao, Pierre Borgnat & Patrick Flandrin 
% 09/2007
%
% Computation of the Statistics Theta for Stationarity Test
%
% Input:  - tfr: matrix of TFRepresentation, positive frequency only
%         - tt2: time vector used
%         - [opt] opt_dist: distance used in dist_locvsglob
%         - [opt] a,b: frequency parameters of dist_locvsglob
%       
% Output:  - theta: statistics used for Stationarity Test
%
% Need: dist_locvsglob
%
% Usage: [theta,Cn_dist,Cn_mean]=statio_test_theta(tfr,tt2,opt_dist,a,b);


function [theta,Cn_dist,Cn_mean]=statio_test_theta(tfr,tt2,opt_dist,a,b);

[l,c]=size(tfr);

try, tt2; catch tt2 = 1:c ; end
try, a; catch a = 0 ; end
try, b; catch b = 0.5 ; end 

Cn_dist = dist_locvsglob(tfr,tt2,opt_dist,a,b) ; 
Cn_mean = mean(Cn_dist); 
theta = sum((Cn_dist - Cn_mean).^2)/length(tt2) ; 

return;
